@@ -8,7 +8,7 @@ from dagster import seven
 from dagster.core.instance import DagsterInstance, InstanceType
 from dagster.core.scheduler.scheduler import ScheduleTickStatus
 from dagster.core.storage.event_log import InMemoryEventLogStorage
-from dagster.core.storage.local_compute_log_manager import NoOpComputeLogManager
+from dagster.core.storage.noop_compute_log_manager import NoOpComputeLogManager
 from dagster.core.storage.root import LocalArtifactStorage
 from dagster.core.storage.runs import InMemoryRunStorage
 from dagster.core.storage.schedules.sqlite import SqliteScheduleStorage
@@ -52,7 +52,7 @@ def get_instance(temp_dir):
         event_storage=InMemoryEventLogStorage(),
         scheduler=FilesytemTestScheduler(temp_dir),
         schedule_storage=SqliteScheduleStorage.from_local(temp_dir),
-        compute_log_manager=NoOpComputeLogManager(temp_dir),
+        compute_log_manager=NoOpComputeLogManager(),
     )
 
 
@@ -65,7 +65,7 @@ def get_instance_with_launcher(temp_dir):
         run_storage=InMemoryRunStorage(),
         event_storage=InMemoryEventLogStorage(),
         schedule_storage=SqliteScheduleStorage.from_local(temp_dir),
-        compute_log_manager=NoOpComputeLogManager(temp_dir),
+        compute_log_manager=NoOpComputeLogManager(),
         run_launcher=test_queue,
     )
 
